add_empty_pop: Modify a dataframe to enable plotting of populations instead of frequencies
Description
The function adds rows at each time point recording the difference between the total population and its maximum value.
Generally there is no need to use this function as Muller_pop_plot calls it automatically.
Usage
add_empty_pop(Muller_df)
Value
A dataframe that can be used as input in Muller_plot.