Learn R Programming

ggmuller (version 0.5.6)

adj_matrix_to_tree: Create a tree object of class "phylo" from an adjacency matrix

Description

Create a tree object of class "phylo" from an adjacency matrix

Usage

adj_matrix_to_tree(edges)

Value

A phylo object.

Arguments

edges

Dataframe comprising an adjacency matrix, in which the first column is the parent and the second is the daughter.

Author

Rob Noble, robjohnnoble@gmail.com

Examples

Run this code
edges1 <- data.frame(Parent = c(1,1,1,3,3), Identity = 2:6)
tree <- adj_matrix_to_tree(edges1)
class(tree)

Run the code above in your browser using DataLab