Learn R Programming

ggmuller (version 0.5.6)

move_down: Move to daughter in adjacency matrix

Description

Returns the first Identity value in the sorted set of daughters. When parent has no daughters, returns the input Identity.

Usage

move_down(edges, parent)

Value

The daughter's Identity.

Arguments

edges

Dataframe comprising an adjacency matrix, with column names "Parent" and "Identity"

parent

number or character string specifying whose daughter is to be found

Author

Rob Noble, robjohnnoble@gmail.com

See Also

move_up move_right

Examples

Run this code
edges1 <- data.frame(Parent = c(1,1,1,3,3), Identity = 2:6)
move_down(edges1, 3)

Run the code above in your browser using DataLab