Learn R Programming

ggmuller (version 0.5.6)

move_right: Move to sibling in adjacency matrix

Description

Returns the next Identity value among the sorted set of siblings. When there is no such sibling, returns the input Identity.

Usage

move_right(edges, identity)

Value

The sibling's Identity.

Arguments

edges

Dataframe comprising an adjacency matrix, with column names "Parent" and "Identity"

identity

number or character string specifying whose sibling is to be found

Author

Rob Noble, robjohnnoble@gmail.com

See Also

move_up move_down

Examples

Run this code
edges1 <- data.frame(Parent = c(1,1,1,3,3), Identity = 2:6)
move_right(edges1, 3)

Run the code above in your browser using DataLab