powered by
Returns the corresponding Parent value. When there is no parent (i.e. at the top of the tree), returns the input Identity.
move_up(edges, identity)
The Parent value.
Dataframe comprising an adjacency matrix, with column names "Parent" and "Identity"
number or character string specifying daughter whose parent is to be found
Rob Noble, robjohnnoble@gmail.com
move_down move_right
move_down
move_right
edges1 <- data.frame(Parent = c(1,1,1,3,3), Identity = 2:6) move_up(edges1, 3)
Run the code above in your browser using DataLab