powered by
Create a tree object of class "phylo" from an adjacency matrix
adj_matrix_to_tree(edges)
A phylo object.
Dataframe comprising an adjacency matrix, in which the first column is the parent and the second is the daughter.
Rob Noble, robjohnnoble@gmail.com
edges1 <- data.frame(Parent = c(1,1,1,3,3), Identity = 2:6) tree <- adj_matrix_to_tree(edges1) class(tree)
Run the code above in your browser using DataLab