powered by
Returns the first Identity value in the sorted set of daughters. When parent has no daughters, returns the input Identity.
move_down(edges, parent)
The daughter's Identity.
Dataframe comprising an adjacency matrix, with column names "Parent" and "Identity"
number or character string specifying whose daughter is to be found
Rob Noble, robjohnnoble@gmail.com
move_up move_right
move_up
move_right
edges1 <- data.frame(Parent = c(1,1,1,3,3), Identity = 2:6) move_down(edges1, 3)
Run the code above in your browser using DataLab